@@ -83,13 +83,13 @@ class BasicGrid(object):
         search will be built on initialization
     shape : tuple, optional
         The shape of the grid array in 2-d space.
-        e.g. for a 1x1 degree global regular grid the shape would be (360,180).
+        e.g. for a 1x1 degree global regular grid the shape would be (180,360).
         if given the grid can be reshaped into the given shape
         this indicates that it is a regular grid and fills the
         attributes self.lon2d and self.lat2d which
         define the grid only be the meridian coordinates(self.lon2d) and
         the coordinates of the circles of latitude(self.lat2d).
-        The shape has to be given as (lon2d, lat2d)
+        The shape has to be given as (lat2d, lon2d)
         It it is not given the shape is set to the length of the input
         lon and lat arrays.
 
@@ -461,8 +461,8 @@ class BasicGrid(object):
                 pos = np.searchsorted(self.gpis[gpisorted], gpi)
                 index = gpisorted[pos]
 
-            index_lat = (index / self.shape[0]).astype(np.int)
-            index_lon = index % self.shape[0]
+            index_lat = (index / self.shape[1]).astype(np.int)
+            index_lon = index % self.shape[1]
             if not iterable:
                 index_lat = index_lat[0]
                 index_lon = index_lon[0]
@@ -624,19 +624,26 @@ class BasicGrid(object):
             Returns True if grids are equal.
         """
         # only test to certain significance for float variables
+        # grids are assumed to be the same if the gpi, lon, lat tuples are the
+        # same
+        idx_gpi = np.argsort(self.gpis)
+        idx_gpi_other = np.argsort(other.gpis)
+        gpisame = np.all(self.gpis[idx_gpi] == other.gpis[idx_gpi_other])
         try:
-            nptest.assert_allclose(self.arrlon, other.arrlon)
+            nptest.assert_allclose(self.arrlon[idx_gpi],
+                                   other.arrlon[idx_gpi_other])
             lonsame = True
         except AssertionError:
             lonsame = False
         try:
-            nptest.assert_allclose(self.arrlat, other.arrlat)
+            nptest.assert_allclose(self.arrlat[idx_gpi],
+                                   other.arrlat[idx_gpi_other])
             latsame = True
         except AssertionError:
             latsame = False
-        gpisame = np.all(self.gpis == other.gpis)
         if self.subset is not None and other.subset is not None:
-            subsetsame = np.all(self.subset == other.subset)
+            subsetsame = np.all(
+                sorted(self.gpis[self.subset]) == sorted(other.gpis[other.subset]))
         elif self.subset is None and other.subset is None:
             subsetsame = True
         else:
@@ -737,7 +744,7 @@ class CellGrid(BasicGrid):
             # find the position where the gpis fit in the sorted array
             pos = np.searchsorted(self.gpis[gpisorted], gpi)
             index = gpisorted[pos]
-            cell = self.activearrcell[index]
+            cell = self.arrcell[index]
 
         if not iterable:
             cell = cell[0]
@@ -944,7 +951,10 @@ class CellGrid(BasicGrid):
             Returns true if equal.
         """
         basicsame = super(CellGrid, self).__eq__(other)
-        cellsame = np.all(self.arrcell == other.arrcell)
+        idx_gpi = np.argsort(self.gpis)
+        idx_gpi_other = np.argsort(other.gpis)
+        cellsame = np.all(self.arrcell[idx_gpi]
+                          == other.arrcell[idx_gpi_other])
         return np.all([basicsame, cellsame])
 
 
@@ -1006,7 +1016,7 @@ def gridfromdims(londim, latdim, **kwargs):
     """
     lons, lats = np.meshgrid(londim, latdim)
     return BasicGrid(lons.flatten(), lats.flatten(),
-                     shape=(len(londim), len(latdim)), **kwargs)
+                     shape=(len(latdim), len(londim)), **kwargs)
 
 
 def genreg_grid(grd_spc_lat=1, grd_spc_lon=1, minlat=-90.0, maxlat=90.0,
